@@ -28,6 +28,32 @@ if sys.platform == 'win32':
 console = Console()
 
 
+def _safe_run_version_check(command: list, timeout: int = 5) -> tuple[bool, str]:
+    """
+    Safely run a version check command.
+
+    Args:
+        command: List of command and arguments
+        timeout: Timeout in seconds
+
+    Returns:
+        Tuple of (success: bool, output: str)
+    """
+    import subprocess
+    try:
+        result = subprocess.run(
+            command,
+            capture_output=True,
+            text=True,
+            timeout=timeout,
+            check=False
+        )
+        return (result.returncode == 0, result.stdout)
+    except (subprocess.SubprocessError, subprocess.TimeoutExpired, OSError):
+        return (False, "")
+
+
+
 def _has_npm_available() -> bool:
     """
     Check if npm is available (handles Windows PATH refresh issues)
@@ -40,7 +66,6 @@ def _has_npm_available() -> bool:
         return True
 
     # Windows: Try running npm.cmd directly (avoids PowerShell execution policy issues)
-    import subprocess
     import platform
     if platform.system() == 'Windows':
         # First, check for npm.cmd (bypasses execution policy)
@@ -50,13 +75,9 @@ def _has_npm_available() -> bool:
         # Try running npm.cmd directly
         npm_cmd_path = shutil.which('npm.cmd')
         if npm_cmd_path:
-            try:
-                result = subprocess.run([npm_cmd_path, '--version'], capture_output=True, timeout=5)
-                if result.returncode == 0:
-                    return True
-            except (subprocess.SubprocessError, FileNotFoundError, OSError, subprocess.TimeoutExpired):
-                # npm.cmd not found or execution failed - continue to check other locations
-                pass
+            success, _ = _safe_run_version_check([npm_cmd_path, '--version'])
+            if success:
+                return True
 
         # Check common Windows install locations for npm.cmd
         common_paths = [
@@ -76,34 +97,25 @@ def _has_pip_available() -> bool:
 
     On Windows, pip is always available via 'py -m pip' even if not in PATH.
     """
+    import platform
+
     # Quick check: is pip in PATH?
     if shutil.which('pip') or shutil.which('pip3'):
         return True
 
     # Windows: Python's pip is always available via 'py -m pip'
-    import subprocess
-    import platform
-    import shutil
     if platform.system() == 'Windows':
         py_path = shutil.which('py')
         if py_path:
-            try:
-                result = subprocess.run([py_path, '-m', 'pip', '--version'], capture_output=True, timeout=5)
-                return result.returncode == 0
-            except (subprocess.SubprocessError, FileNotFoundError, OSError, subprocess.TimeoutExpired):
-                # py launcher not available - continue to Unix fallback
-                pass
+            success, _ = _safe_run_version_check([py_path, '-m', 'pip', '--version'])
+            if success:
+                return True
 
     # Unix: Try python3 -m pip
-    try:
-        import subprocess
-        import shutil
-        python3_path = shutil.which('python3')
-        if python3_path:
-            result = subprocess.run([python3_path, '-m', 'pip', '--version'], capture_output=True, timeout=5)
-            return result.returncode == 0
-    except (subprocess.SubprocessError, FileNotFoundError, OSError, subprocess.TimeoutExpired):
-        pass
+    python3_path = shutil.which('python3')
+    if python3_path:
+        success, _ = _safe_run_version_check([python3_path, '-m', 'pip', '--version'])
+        return success
     # python3 not available or pip not installed
     return False
 
@@ -140,9 +152,9 @@ def _safe_print(*args, **kwargs):
             try:
                 print(ascii_text)
             except Exception:
-                # Final fallback failed - suppress to prevent crash during output
-                # This is intentionally silent as there's nothing more we can do
-                pass
+                # Final fallback failed - cannot print to console
+                # Silently continue to prevent crash during output
+                return  # Explicit return instead of pass
 
 console.print = _safe_print
 
@@ -558,6 +570,253 @@ def _handle_batch_install(target, auto_install):
     console.print()
 
 
+def _check_runtime_dependencies(
+    missing_tools: list,
+    npm_tools_failed: list,
+    platform_info,
+    pm,
+    use_latest: bool = False,
+    yes: bool = False
+) -> None:
+    """
+    Check for runtime dependencies (Node.js/npm, PHP, Java) and offer to install them.
+
+    Args:
+        missing_tools: List of all tools that were attempted to be installed
+        npm_tools_failed: List of npm tools that failed due to missing npm
+        platform_info: Platform information object
+        pm: Package manager enum
+        use_latest: Whether to install latest versions
+        yes: Auto-accept prompts (--yes flag)
+    """
+    # Only run on Windows
+    if platform_info.os_type.value != 'windows':
+        return
+
+    # Define which tools need which runtimes
+    php_tools = {'phpstan'}
+    java_tools = {'checkstyle', 'ktlint', 'scalastyle', 'codenarc'}
+
+    # Check which runtime-dependent tools are in the missing list
+    php_tools_missing = [t for t in missing_tools if t in php_tools]
+    java_tools_missing = [t for t in missing_tools if t in java_tools]
+
+    # ========================================
+    # Node.js / npm auto-install
+    # ========================================
+    if npm_tools_failed:
+        # Check if we've already attempted Node.js installation this session
+        global _nodejs_install_attempted
+        if '_nodejs_install_attempted' not in globals():
+            _nodejs_install_attempted = False
+
+        if _nodejs_install_attempted:
+            console.print("")
+            console.print(f"[yellow]⚠️  {len(npm_tools_failed)} tool{'s' if len(npm_tools_failed) > 1 else ''} require Node.js (npm)[/yellow]")
+            console.print("[dim]   Node.js installation was already attempted. Please restart your terminal.[/dim]")
+            return
+
+        from medusa.platform import PackageManager
+        if pm in (PackageManager.WINGET, PackageManager.CHOCOLATEY):
+            console.print("")
+            console.print(f"[yellow]⚠️  {len(npm_tools_failed)} tool{'s' if len(npm_tools_failed) > 1 else ''} require Node.js (npm)[/yellow]")
+
+            # Check if running in non-interactive mode (CI environment)
+            if not sys.stdin.isatty():
+                console.print("[yellow]   Non-interactive mode detected, skipping Node.js installation[/yellow]")
+                return  # Skip Node.js prompt in CI
+
+            # Mark that we're attempting Node.js installation
+            _nodejs_install_attempted = True
+
+            # Prompt user
+            if not yes:
+                response = Prompt.ask(
+                    "   Install Node.js via winget to enable these tools?",
+                    choices=["y", "Y", "n", "N"],
+                    default="y",
+                    show_choices=False
+                )
+                install_nodejs = response.upper() == "Y"
+            else:
+                install_nodejs = True
+
+            if install_nodejs:
+                # First check if Node.js is already installed
+                console.print("\n[cyan]Checking for existing Node.js installation...[/cyan]")
+                nodejs_already_installed = False
+                node_path = shutil.which('node')
+                if node_path:
+                    success, output = _safe_run_version_check([node_path, '--version'])
+                    if success:
+                        nodejs_already_installed = True
+                        console.print(f"[green]✓[/green] Node.js found: {output.strip()}")
+                        console.print("[yellow]   But npm not in PATH. Attempting to fix...[/yellow]")
+                if not nodejs_already_installed:
+                    console.print("[dim]   Node.js not found, installing...[/dim]")
+
+                if not nodejs_already_installed:
+                    console.print("\n[cyan]Installing Node.js via winget...[/cyan]")
+
+                # Install Node.js via winget (even if already installed, to ensure npm is available)
+                from medusa.platform.installers import WingetInstaller
+                winget_installer = WingetInstaller()
+                nodejs_success = False
+
+                winget_path = shutil.which('winget')
+                if winget_path:
+                    try:
+                        success, output = _safe_run_version_check(
+                            [winget_path, 'install', '--id', 'OpenJS.NodeJS', '--accept-source-agreements', '--accept-package-agreements'],
+                            timeout=120
+                        )
+                        output_lower = output.lower() if output else ''
+                        nodejs_success = (
+                            success or
+                            'already installed' in output_lower or
+                            'no available upgrade found' in output_lower
+                        )
+
+                        # Show winget output for debugging
+                        if not success:
+                            console.print(f"[dim]Winget output: {output[:300]}[/dim]")
+                    except Exception as e:
+                        nodejs_success = False
+                        console.print(f"[red]Error during installation: {str(e)[:100]}[/red]")
+
+                if nodejs_success:
+                    console.print("[green]✅ Node.js installed successfully[/green]")
+
+                    # Refresh PATH
+                    from medusa.platform.installers.windows import refresh_windows_path
+                    refresh_windows_path()
+                    console.print("[dim]   PATH refreshed from registry[/dim]")
+
+                    # Verify npm is now available
+                    console.print("\n[cyan]Checking for npm...[/cyan]")
+                    npm_path = shutil.which('npm.cmd') or shutil.which('npm')
+
+                    if npm_path:
+                        console.print(f"[green]✓[/green] npm found at: {npm_path}")
+                        # Verify npm works
+                        try:
+                            success, output = _safe_run_version_check([npm_path, '--version'])
+                            if success:
+                                console.print(f"[green]✓[/green] npm version: {output.strip()}")
+                            else:
+                                console.print(f"[yellow]⚠[/yellow] npm found but returned error")
+                        except Exception as e:
+                            console.print(f"[yellow]⚠[/yellow] npm found but test failed: {str(e)[:50]}")
+                    else:
+                        console.print("[yellow]✗[/yellow] npm not found in PATH")
+                        console.print("[dim]   This usually means you need to restart your terminal[/dim]")
+
+                    # Retry npm tools
+                    console.print("\n[cyan]Retrying npm tools...[/cyan]\n")
+                    from medusa.platform.installers import NpmInstaller, ToolMapper
+                    npm_installer = NpmInstaller() if npm_path else None
+
+                    if npm_installer:
+                        npm_installed = 0
+                        for tool in npm_tools_failed:
+                            console.print(f"[cyan]Installing {tool}...[/cyan]")
+                            npm_package = ToolMapper.get_package_name(tool, 'npm')
+                            console.print(f"  → Trying npm: {npm_package}")
+
+                            if npm_installer.install(tool, use_latest=use_latest):
+                                console.print(f"  [green]✅ Installed via npm[/green]\n")
+                                npm_installed += 1
+                                # Mark tool as installed in cache
+                                from medusa.platform.tool_cache import ToolCache
+                                cache = ToolCache()
+                                cache.mark_installed(tool)
+                            else:
+                                console.print(f"  [red]❌ Failed[/red]\n")
+
+                        if npm_installed > 0:
+                            console.print(f"[green]✅ Installed {npm_installed}/{len(npm_tools_failed)} npm tools[/green]")
+                    else:
+                        console.print("[yellow]⚠️  npm still not available. Try restarting your terminal.[/yellow]")
+                        console.print("[dim]   Node.js may need a terminal restart to be detected.[/dim]")
+                        return
+                else:
+                    console.print("[red]❌ Failed to install Node.js[/red]")
+                    console.print("[yellow]You can manually install Node.js from: https://nodejs.org[/yellow]")
+                    return
+
+    # ========================================
+    # PHP auto-install
+    # ========================================
+    if php_tools_missing and not shutil.which('php'):
+        console.print()
+        console.print(f"[bold yellow]⚠️  {len(php_tools_missing)} tool{'s' if len(php_tools_missing) > 1 else ''} require PHP runtime:[/bold yellow]")
+        for t in php_tools_missing:
+            console.print(f"   • {t}")
+        console.print()
+
+        if not yes:
+            response = Prompt.ask(
+                "   Install PHP via winget to enable these tools?",
+                choices=["y", "Y", "n", "N"],
+                default="y",
+                show_choices=False
+            )
+            install_php = response.upper() == "Y"
+        else:
+            install_php = True
+
+        if install_php:
+            console.print("\n[cyan]Installing PHP via winget...[/cyan]")
+            from medusa.platform.installers import WingetInstaller
+            winget_installer = WingetInstaller()
+            winget_path = shutil.which('winget')
+
+            if winget_path:
+                try:
+                    success, output = _safe_run_version_check(
+                        [winget_path, 'install', '--id', 'PHP.PHP.8.4', '--accept-source-agreements', '--accept-package-agreements'],
+                        timeout=120
+                    )
+                    output_lower = output.lower() if output else ''
+                    php_success = (
+                        success or
+                        'already installed' in output_lower or
+                        'no available upgrade found' in output_lower
+                    )
+
+                    if php_success:
+                        console.print("[green]✅ PHP installed successfully[/green]")
+                        console.print("[dim]   You may need to restart your terminal for PHP to be available[/dim]")
+                    else:
+                        console.print("[red]❌ Failed to install PHP[/red]")
+                        console.print("[yellow]You can manually install PHP from: https://windows.php.net/download/[/yellow]")
+                except Exception as e:
+                    console.print(f"[red]Error during installation: {str(e)[:100]}[/red]")
+            else:
+                console.print("[red]❌ winget not found[/red]")
+        else:
+            console.print("[yellow]Skipping PHP installation[/yellow]")
+            console.print("[dim]   phpstan will not work without PHP runtime[/dim]")
+
+    # ========================================
+    # Java runtime check (informational only)
+    # ========================================
+    if java_tools_missing and not shutil.which('java'):
+        console.print()
+        console.print(f"[bold yellow]⚠️  {len(java_tools_missing)} tool{'s' if len(java_tools_missing) > 1 else ''} require Java runtime (not auto-installed for security):[/bold yellow]")
+        for t in java_tools_missing:
+            tool_desc = {
+                'checkstyle': 'Java linter',
+                'ktlint': 'Kotlin linter',
+                'scalastyle': 'Scala linter',
+                'codenarc': 'Groovy linter'
+            }.get(t, 'JVM linter')
+            console.print(f"   • {t} ({tool_desc})")
+        console.print()
+        console.print("[dim]   If you install Java manually, these tools will become available.[/dim]")
+        console.print("[dim]   We don't auto-install Java due to security concerns.[/dim]")
+
+
 def _install_tools(tools: list, use_latest: bool = False):
     """
     Install a list of tools
@@ -658,158 +917,15 @@ def _install_tools(tools: list, use_latest: bool = False):
     if failed > 0:
         console.print(f"[yellow]⚠️  {failed} tools failed to install (may need manual installation)[/yellow]")
 
-    # Offer to install Node.js if npm tools failed on Windows
-    if npm_tools_failed and platform_info.os_type.value == 'windows':
-        # Check if we've already attempted Node.js installation this session
-        global _nodejs_install_attempted
-        if '_nodejs_install_attempted' not in globals():
-            _nodejs_install_attempted = False
-
-        if _nodejs_install_attempted:
-            console.print("")
-            console.print(f"[yellow]⚠️  {len(npm_tools_failed)} tool{'s' if len(npm_tools_failed) > 1 else ''} require Node.js (npm)[/yellow]")
-            console.print("[dim]   Node.js installation was already attempted. Please restart your terminal.[/dim]")
-            return
-
-        from medusa.platform import PackageManager
-        if pm == PackageManager.WINGET:
-            console.print("")
-            console.print(f"[yellow]⚠️  {len(npm_tools_failed)} tool{'s' if len(npm_tools_failed) > 1 else ''} require Node.js (npm)[/yellow]")
-
-            # Check if running in non-interactive mode (CI environment)
-            if not sys.stdin.isatty():
-                console.print("[yellow]   Non-interactive mode detected, skipping Node.js installation[/yellow]")
-                return  # Skip Node.js prompt in CI
-
-            # Mark that we're attempting Node.js installation
-            _nodejs_install_attempted = True
-
-            # Prompt user
-            response = Prompt.ask(
-                "   Install Node.js via winget to enable these tools?",
-                choices=["y", "Y", "n", "N"],
-                default="y",
-                show_choices=False
-            )
-
-            if response.upper() == "Y":
-                # First check if Node.js is already installed
-                console.print("\n[cyan]Checking for existing Node.js installation...[/cyan]")
-                nodejs_already_installed = False
-                node_path = shutil.which('node')
-                if node_path:
-                    try:
-                        import subprocess
-                        node_check = subprocess.run([node_path, '--version'], capture_output=True, text=True, timeout=5)
-                        if node_check.returncode == 0:
-                            nodejs_already_installed = True
-                            console.print(f"[green]✓[/green] Node.js found: {node_check.stdout.strip()}")
-                            console.print("[yellow]   But npm not in PATH. Attempting to fix...[/yellow]")
-                    except:
-                        pass
-                if not nodejs_already_installed:
-                    console.print("[dim]   Node.js not found, installing...[/dim]")
-
-                if not nodejs_already_installed:
-                    console.print("\n[cyan]Installing Node.js via winget...[/cyan]")
-
-                # Install Node.js via winget (even if already installed, to ensure npm is available)
-                winget_installer = WingetInstaller()
-                nodejs_success = False
-
-                winget_path = shutil.which('winget')
-                if winget_path:
-                    try:
-                        import subprocess
-                        result = subprocess.run(
-                            [winget_path, 'install', '--id', 'OpenJS.NodeJS', '--accept-source-agreements', '--accept-package-agreements'],
-                            capture_output=True,
-                            text=True,
-                            timeout=120
-                        )
-                        output = result.stdout.lower() if result.stdout else ''
-                        nodejs_success = (
-                            result.returncode == 0 or
-                            'already installed' in output or
-                            'no available upgrade found' in output
-                        )
-
-                        # Show winget output for debugging
-                        if result.returncode != 0:
-                            console.print(f"[dim]Winget output: {result.stdout[:300]}[/dim]")
-                    except Exception as e:
-                        nodejs_success = False
-                        console.print(f"[red]Error during installation: {str(e)[:100]}[/red]")
-
-                if nodejs_success:
-                    console.print("[green]✅ Node.js installed successfully[/green]")
-
-                    # Refresh PATH
-                    if platform_info.os_type.value == 'windows':
-                        from medusa.platform.installers.windows import refresh_windows_path
-                        refresh_windows_path()
-                        console.print("[dim]   PATH refreshed from registry[/dim]")
-
-                    # Verify npm is now available
-                    console.print("\n[cyan]Checking for npm...[/cyan]")
-                    # On Windows, look for npm.cmd explicitly to avoid shell=True
-                    if platform_info.os_type.value == 'windows':
-                        npm_path = shutil.which('npm.cmd') or shutil.which('npm')
-                    else:
-                        npm_path = shutil.which('npm')
-
-                    if npm_path:
-                        console.print(f"[green]✓[/green] npm found at: {npm_path}")
-                        # Verify npm works (no shell=True needed with explicit path)
-                        try:
-                            npm_version_check = subprocess.run(
-                                [npm_path, '--version'],
-                                capture_output=True,
-                                text=True,
-                                timeout=5,
-                                shell=False
-                            )
-                            if npm_version_check.returncode == 0:
-                                console.print(f"[green]✓[/green] npm version: {npm_version_check.stdout.strip()}")
-                            else:
-                                console.print(f"[yellow]⚠[/yellow] npm found but returned error: {npm_version_check.stderr[:100]}")
-                        except Exception as e:
-                            console.print(f"[yellow]⚠[/yellow] npm found but test failed: {str(e)[:50]}")
-                    else:
-                        console.print("[yellow]✗[/yellow] npm not found in PATH")
-                        console.print("[dim]   This usually means you need to restart your terminal[/dim]")
-
-                    # Retry npm tools
-                    console.print("\n[cyan]Retrying npm tools...[/cyan]\n")
-                    npm_installer = NpmInstaller() if npm_path else None
-
-                    if npm_installer:
-                        npm_installed = 0
-                        for tool in npm_tools_failed:
-                            console.print(f"[cyan]Installing {tool}...[/cyan]")
-                            npm_package = ToolMapper.get_package_name(tool, 'npm')
-                            console.print(f"  → Trying npm: {npm_package}")
-
-                            if npm_installer.install(tool, use_latest=use_latest):
-                                console.print(f"  [green]✅ Installed via npm[/green]\n")
-                                npm_installed += 1
-                                # Mark tool as installed in cache
-                                from medusa.platform.tool_cache import ToolCache
-                                cache = ToolCache()
-                                cache.mark_installed(tool)
-                            else:
-                                console.print(f"  [red]❌ Failed[/red]\n")
-
-                        if npm_installed > 0:
-                            console.print(f"[green]✅ Installed {npm_installed}/{len(npm_tools_failed)} npm tools[/green]")
-                    else:
-                        console.print("[yellow]⚠️  npm still not available. Try restarting your terminal.[/yellow]")
-                        console.print("[dim]   Node.js may need a terminal restart to be detected.[/dim]")
-                        return  # Don't ask again this session
-                else:
-                    console.print("[red]❌ Failed to install Node.js[/red]")
-                    console.print("[yellow]You can manually install Node.js from: https://nodejs.org[/yellow]")
-                    return  # Don't ask again this session
+    # Check for runtime dependencies (Node.js/npm, PHP, Java)
+    _check_runtime_dependencies(
+        missing_tools=tools,
+        npm_tools_failed=npm_tools_failed,
+        platform_info=platform_info,
+        pm=pm,
+        use_latest=use_latest,
+        yes=False  # _install_tools doesn't have a yes parameter
+    )
 
 
 def print_banner():
@@ -1062,13 +1178,21 @@ def init(ide, force, install):
 
         if install or click.confirm(f"\nInstall {len(missing_tools)} missing tools for your project?", default=False):
             console.print("[cyan]Installing missing tools...[/cyan]")
-            # Import installer logic
-            from medusa.platform import get_platform_info
-            from medusa.platform.installers import AptInstaller, HomebrewInstaller, WingetInstaller, ChocolateyInstaller, NpmInstaller, PipInstaller
+            # Call the install command directly with --all --yes
+            import sys
+            import subprocess
 
-            platform_info = get_platform_info()
-            # This would call the actual installation - skipping for safety in init
-            console.print("[yellow]Note: Run 'medusa install --all' to install missing tools[/yellow]")
+            cmd = [sys.executable, '-m', 'medusa', 'install', '--all', '--yes']
+            result = subprocess.run(
+                cmd,
+                capture_output=False,
+                text=True,
+                check=False
+            )
+            if result.returncode != 0:
+                console.print("[yellow]⚠️  Some tools may not have installed successfully[/yellow]")
+                console.print("[dim]You can retry with: medusa install --all[/dim]")
+            console.print()  # Extra newline for spacing
 
     # Step 3: Create configuration
     console.print("\n[bold cyan]Step 3/4: Creating configuration...[/bold cyan]")
@@ -1396,10 +1520,147 @@ def install(tool, check, all, yes, use_latest, debug):
                 else:
                     console.print("[yellow]Skipping Chocolatey installation[/yellow]\n")
 
+        # ========================================
+        # Pre-scan phase: Detect runtime dependencies
+        # ========================================
+        npm_tools_needed = []
+        php_tools_needed = []
+        java_tools_needed = []
+
+        for tool in missing_tools:
+            # Check if tool needs npm
+            npm_package = ToolMapper.get_package_name(tool, 'npm')
+            if npm_package and not npm_installer:
+                # Tool has npm package but npm isn't available
+                npm_tools_needed.append(tool)
+
+            # Check if tool needs PHP
+            if tool == 'phpstan' and not shutil.which('php'):
+                php_tools_needed.append(tool)
+
+            # Check if tool needs Java
+            if tool in {'checkstyle', 'ktlint', 'scalastyle', 'codenarc'} and not shutil.which('java'):
+                java_tools_needed.append(tool)
+
+        # ========================================
+        # Runtime installation phase
+        # ========================================
+        if npm_tools_needed or php_tools_needed or java_tools_needed:
+            console.print("[bold]Runtime Dependencies Detected:[/bold]")
+
+            # Node.js / npm
+            if npm_tools_needed:
+                console.print(f"  • Node.js needed for {len(npm_tools_needed)} tool{'s' if len(npm_tools_needed) > 1 else ''}: {', '.join(npm_tools_needed[:3])}{'...' if len(npm_tools_needed) > 3 else ''}")
+
+            # PHP
+            if php_tools_needed:
+                console.print(f"  • PHP needed for {len(php_tools_needed)} tool{'s' if len(php_tools_needed) > 1 else ''}: {', '.join(php_tools_needed)}")
+
+            # Java (info only)
+            if java_tools_needed:
+                console.print(f"  • Java needed for {len(java_tools_needed)} tool{'s' if len(java_tools_needed) > 1 else ''}: {', '.join(java_tools_needed[:3])}{'...' if len(java_tools_needed) > 3 else ''} [dim](not auto-installed for security)[/dim]")
+
+            console.print()
+
+        # Install Node.js if needed
+        if npm_tools_needed and platform_info.os_type.value == 'windows':
+            from medusa.platform import PackageManager
+            if pm in (PackageManager.WINGET, PackageManager.CHOCOLATEY):
+                if not yes:
+                    install_nodejs = click.confirm(f"Install Node.js to enable {len(npm_tools_needed)} npm tools?", default=True)
+                else:
+                    install_nodejs = True
+
+                if install_nodejs:
+                    console.print("\n[cyan]Installing Node.js via winget...[/cyan]")
+                    winget_path = shutil.which('winget')
+
+                    if winget_path:
+                        try:
+                            success, output = _safe_run_version_check(
+                                [winget_path, 'install', '--id', 'OpenJS.NodeJS', '--accept-source-agreements', '--accept-package-agreements'],
+                                timeout=120
+                            )
+                            output_lower = output.lower() if output else ''
+                            nodejs_success = (
+                                success or
+                                'already installed' in output_lower or
+                                'no available upgrade found' in output_lower
+                            )
+
+                            if nodejs_success:
+                                console.print("[green]✅ Node.js installed successfully[/green]")
+
+                                # Refresh PATH
+                                from medusa.platform.installers.windows import refresh_windows_path
+                                refresh_windows_path()
+
+                                # Re-initialize npm_installer now that npm is available
+                                from medusa.platform.installers import NpmInstaller
+                                npm_installer = NpmInstaller() if shutil.which('npm.cmd') or shutil.which('npm') else None
+                                console.print(f"[green]✓[/green] npm is now available\n")
+                            else:
+                                console.print("[red]❌ Failed to install Node.js[/red]\n")
+                        except Exception as e:
+                            console.print(f"[red]Error: {str(e)[:100]}[/red]\n")
+                    else:
+                        console.print("[red]❌ winget not found[/red]\n")
+                else:
+                    console.print("[yellow]Skipping Node.js installation[/yellow]\n")
+
+        # Install PHP if needed
+        if php_tools_needed and platform_info.os_type.value == 'windows':
+            from medusa.platform import PackageManager
+            if pm in (PackageManager.WINGET, PackageManager.CHOCOLATEY):
+                if not yes:
+                    install_php = click.confirm(f"Install PHP to enable phpstan?", default=True)
+                else:
+                    install_php = True
+
+                if install_php:
+                    console.print("\n[cyan]Installing PHP via winget...[/cyan]")
+                    winget_path = shutil.which('winget')
+
+                    if winget_path:
+                        try:
+                            success, output = _safe_run_version_check(
+                                [winget_path, 'install', '--id', 'PHP.PHP.8.4', '--accept-source-agreements', '--accept-package-agreements'],
+                                timeout=120
+                            )
+                            output_lower = output.lower() if output else ''
+                            php_success = (
+                                success or
+                                'already installed' in output_lower or
+                                'no available upgrade found' in output_lower
+                            )
+
+                            if php_success:
+                                console.print("[green]✅ PHP installed successfully[/green]")
+                                console.print("[dim]   You may need to restart your terminal for PHP to be available[/dim]\n")
+                            else:
+                                console.print("[red]❌ Failed to install PHP[/red]\n")
+                        except Exception as e:
+                            console.print(f"[red]Error: {str(e)[:100]}[/red]\n")
+                    else:
+                        console.print("[red]❌ winget not found[/red]\n")
+                else:
+                    console.print("[yellow]Skipping PHP installation[/yellow]\n")
+
+        # Show Java message (no auto-install)
+        if java_tools_needed:
+            console.print(f"[yellow]⚠️  Java runtime required for {len(java_tools_needed)} tool{'s' if len(java_tools_needed) > 1 else ''}[/yellow]")
+            console.print("[dim]   We don't auto-install Java due to security concerns[/dim]")
+            console.print(f"[dim]   Tools: {', '.join(java_tools_needed)}[/dim]\n")
+
+        # ========================================
+        # Tool installation phase
+        # ========================================
         installed = 0
         failed = 0
         failed_details = []  # Track why each tool failed
+        npm_tools_failed = []  # Track npm tools that failed due to missing npm
 
+        console.print("[bold]Installing Tools:[/bold]")
         for tool_name in missing_tools:
             console.print(f"[cyan]Installing {tool_name}...[/cyan]")
 
@@ -1442,6 +1703,10 @@ def install(tool, check, all, yes, use_latest, debug):
                 installer_name = 'pip'
                 package_name = pip_package
 
+            # Track npm tools that failed due to missing npm
+            if npm_package and not npm_installer and not best_installer:
+                npm_tools_failed.append(tool_name)
+
             # Install using the best installer
             if best_installer:
                 console.print(f"  → Installing {tool_name} via {installer_name}: {package_name}")
@@ -1496,7 +1761,23 @@ def install(tool, check, all, yes, use_latest, debug):
                         failed += 1
                         failed_details.append((tool_name, installer_name))
             else:
-                # Try ecosystem detection before giving up
+                # On Windows, try custom PowerShell installers FIRST (more reliable than ecosystem)
+                if platform_info.os_type.value == 'windows':
+                    from medusa.platform.installers import WindowsCustomInstaller
+                    if WindowsCustomInstaller.can_install(tool_name):
+                        console.print(f"  → Using custom Windows installer...")
+                        if WindowsCustomInstaller.install(tool_name, debug=debug):
+                            console.print(f"  [green]✅ Installed successfully[/green]\n")
+                            installed += 1
+                            from medusa.platform.tool_cache import ToolCache
+                            cache = ToolCache()
+                            cache.mark_installed(tool_name)
+                            continue  # Skip to next tool
+                        else:
+                            console.print(f"  [red]❌ Custom installer failed[/red]")
+                            # Fall through to ecosystem check
+
+                # Try ecosystem detection as fallback
                 from medusa.platform.installers.base import EcosystemDetector
 
                 ecosystem_result = EcosystemDetector.detect_ecosystem(tool_name)
@@ -1518,24 +1799,7 @@ def install(tool, check, all, yes, use_latest, debug):
                         failed += 1
                         failed_details.append((tool_name, ecosystem_name))
                 else:
-                    # On Windows, try custom .bat installers as final fallback
-                    if platform_info.os_type.value == 'windows':
-                        from medusa.platform.installers import WindowsCustomInstaller
-                        if WindowsCustomInstaller.can_install(tool_name):
-                            console.print(f"  → Using custom Windows installer...")
-                            if WindowsCustomInstaller.install(tool_name, debug=debug):
-                                console.print(f"  [green]✅ Installed successfully[/green]\n")
-                                installed += 1
-                                from medusa.platform.tool_cache import ToolCache
-                                cache = ToolCache()
-                                cache.mark_installed(tool_name)
-                                continue  # Skip to next tool
-                            else:
-                                console.print(f"  [red]❌ Custom installer failed[/red]")
-                                # Fall through to ecosystem check
-
                     # Check if ecosystem exists but not found
-                    from medusa.platform.installers.base import EcosystemDetector
                     if tool_name in EcosystemDetector.ECOSYSTEM_MAP:
                         ecosystems = EcosystemDetector.ECOSYSTEM_MAP[tool_name]['ecosystems']
                         console.print(f"  → Looking for {ecosystems[0]}... [red]✗ Not found[/red]")
