@@ -26,8 +26,7 @@ class GroovyScanner(BaseScanner):
                 error_message="CodeNarc not installed. Install from: https://codenarc.github.io/CodeNarc/")
 
         try:
-            result = subprocess.run([str(self.tool_path), "-basedir=" + str(file_path.parent), "-includes=" + file_path.name],
-                capture_output=True, text=True, timeout=30)
+            result = self._run_command([str(self.tool_path), "-basedir=" + str(file_path.parent), "-includes=" + file_path.name], timeout=30)
             issues = []
             # CodeNarc parsing would go here - simplified for brevity
             return ScannerResult(file_path=file_path, scanner_name=self.name, issues=issues, scan_time=time.time() - start_time, success=True)
